# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

## [0.2.0] - 2025-03-27

### Added

- Added new `StringFormatter` class in `i18n/formatter.py` for handling string formatting logic

### Changed

- Refactored `I18N` class to use new `StringFormatter` for string formatting

### Fixed

- Fixed string formatting error handling

## [0.1.0] - 2025-03-18

### Added

- Initial release
